@@ -1,6 +1,5 @@
 import sys
 import logging
-import typing as T
 from enum import Enum
 
 log = logging.getLogger(__name__)
@@ -30,6 +29,9 @@ def prologue_handler(opts) -> None:
     log.info(f"Running {__file__} with {opts}")
 
 
+setup_logger = prologue_handler
+
+
 def epilogue_handler(exit_code: int, run_time_sec: float) -> None:
     log.info(
         f"Completed running {__file__} with exit code {exit_code} in {run_time_sec} sec."
